<?php
/**
 * colorpalette functions and definitions
 *
 * @package colorpalette
 * @since colorpalette 1.0
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 *
 * @since colorpalette 1.0
 */
if ( ! isset( $content_width ) )
	$content_width = 608; /* pixels */

if ( ! function_exists( 'colorpalette_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 *
 * @since colorpalette 1.0
 */
function colorpalette_setup() {

	/**
	 * Custom template tags for this theme.
	 */
	require( get_template_directory() . '/inc/template-tags.php' );

	/**
	 * Custom functions that act independently of the theme templates
	 */
	require( get_template_directory() . '/inc/extras.php' );
	
	
	/**
	 * Load up our theme options page and related code.
	*/
	require( get_template_directory() . '/inc/theme-options.php' );


	/**
	 * Make theme available for translation
	 * Translations can be filed in the /languages/ directory
	 * If you're building a theme based on colorpalette, use a find and replace
	 * to change 'colorpalette' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'colorpalette', get_template_directory() . '/languages' );

	/**
	 * Add default posts and comments RSS feed links to head
	 */
	add_theme_support( 'automatic-feed-links' );

	/**
	 * Enable support for Post Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );

	/**
	 * This theme uses wp_nav_menu() in one location.
	 */
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'colorpalette' ),
	) );

	/**
	 * Add support for the Aside Post Formats
	 */
	add_theme_support( 'post-formats', array( 'aside', 'quote' ) );
	
	/**
	 * Add styling for editor for both LTR and RTL
	 */
	add_editor_style();
}
endif; // colorpalette_setup
add_action( 'after_setup_theme', 'colorpalette_setup' );

/**
 * Register widgetized area and update sidebar with default widgets
 *
 * @since colorpalette 1.0
 */
function colorpalette_widgets_init() {
	register_sidebar( array(
		'name' => __( 'Sidebar', 'colorpalette' ),
		'id' => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget' => '</div></aside>',
		'before_title' => '<h1 class="widget-title">',
		'after_title' => '</h1>',
	) );
	register_sidebar( array(
		'name' => __( 'First Footer Area', 'colorpalette' ),
		'id' => 'footer-left',
		'before_widget' => '',
		'after_widget' => '',
		'before_title' => '<h3>',
		'after_title' => '</h3>',
	) );
	register_sidebar( array(
		'name' => __( 'Middle Footer Area', 'colorpalette' ),
		'id' => 'footer-center',
		'before_widget' => '',
		'after_widget' => '',
		'before_title' => '<h3>',
		'after_title' => '</h3>',
	) );
	register_sidebar( array(
		'name' => __( 'Last Footer Area', 'colorpalette' ),
		'id' => 'footer-right',
		'before_widget' => '',
		'after_widget' => '',
		'before_title' => '<h3>',
		'after_title' => '</h3>',
	) );
}
add_action( 'widgets_init', 'colorpalette_widgets_init' );

/**
 * Enqueue scripts and styles
 */
function colorpalette_scripts() {
	wp_enqueue_style( 'style', get_stylesheet_uri() );
	
	wp_enqueue_style('googleFonts', 'http://fonts.googleapis.com/css?family=Kameron|Bad+Script');


	wp_enqueue_script( 'small-menu', get_template_directory_uri() . '/js/small-menu.js', array( 'jquery' ), '20120206', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	if ( is_singular() && wp_attachment_is_image() ) {
		wp_enqueue_script( 'keyboard-image-navigation', get_template_directory_uri() . '/js/keyboard-image-navigation.js', array( 'jquery' ), '20120202' );
	}
}
add_action( 'wp_enqueue_scripts', 'colorpalette_scripts' );

