<?php
/**
 * Custom functions that act independently of the theme templates
 *
 * Eventually, some of the functionality here could be replaced by core features
 *
 * @package colorpalette
 * @since colorpalette 1.0
 */

if ( ! function_exists( 'colorpalette_page_menu_args' ) ) :
/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 *
 * @since colorpalette 1.0
 */
function colorpalette_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'colorpalette_page_menu_args' );

endif; //colorpalette_page_menu_args


if ( ! function_exists( 'colorpalette_body_classes' ) ) :
/**
 * Adds custom classes to the array of body classes.
 *
 * @since colorpalette 1.0
 */
function colorpalette_body_classes( $classes ) {
	// Adds a class of group-blog to blogs with more than 1 published author
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	return $classes;
}
add_filter( 'body_class', 'colorpalette_body_classes' );
endif; //colorpalette_body_classes

if ( ! function_exists( 'colorpalette_enhanced_image_navigation' ) ) :
/**
 * Filter in a link to a content ID attribute for the next/previous image links on image attachment pages
 *
 * @since colorpalette 1.0
 */
function colorpalette_enhanced_image_navigation( $url, $id ) {
	if ( ! is_attachment() && ! wp_attachment_is_image( $id ) )
		return $url;

	$image = get_post( $id );
	if ( ! empty( $image->post_parent ) && $image->post_parent != $id )
		$url .= '#main';

	return $url;
}
add_filter( 'attachment_link', 'colorpalette_enhanced_image_navigation', 10, 2 );
endif; //colorpalette_enhanced_image_navigation

if ( ! function_exists( 'colorpalette_wp_title' ) ) :
/**
 * Filters wp_title to print a neat <title> tag based on what is being viewed.
 *
 * @since colorpalette 1.1
 */
function colorpalette_wp_title( $title, $sep ) {
	global $page, $paged;

	if ( is_feed() )
		return $title;

	// Add the blog name
	$title .= get_bloginfo( 'name' );

	// Add the blog description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		$title .= " $sep $site_description";

	// Add a page number if necessary:
	if ( $paged >= 2 || $page >= 2 )
		$title .= " $sep " . sprintf( __( 'Page %s', 'colorpalette' ), max( $paged, $page ) );

	return $title;
}
add_filter( 'wp_title', 'colorpalette_wp_title', 10, 2 );
endif; //colorpalette_wp_title